<?php

    class PHP_Script_Evaluation_Condition extends Reactor_Condition
    {
        protected $tpl = 'php_script_evaluation.php';
        protected $name = 'PHP script evaluates to';
		
		public static $registration = array(
			CONDITION_NAME => 'Evaluate PHP Script',
			CONDITION_CATEGORY => 'Code Evaluation',
			CONDITION_DESCRIPTION => 'Runs PHP code and evaluates the output.',
			CONDITION_AUTHOR => 'Jeremy Yunis, Nagios Enterprises, LLC',
			CONDITION_VERSION => '1.0',
			CONDITION_DATE => '01/22/2013', //Last version update
			CONDITION_AUTHLEVEL => 0,  // 0 - everyone | 1 - Admin only
			CONDITION_TYPE => 'core', //core | user. core modules can't be deleted
			CONDITION_META => array(),	//Misc information	
		); 				
		
        protected $fields = array(
            'script' => array(
                'label' => 'PHP script',
                'validate' => 'trim|required|callback_strip_php_tags'
            ),
            'comparison_type' => array(
                'label' => 'comparison type',
                'validate' => 'trim|required',
            ),
            'value' => array(
                'label' => 'value',
                'validate' => 'trim|required|xss_clean|prep_for_form',
            ),
        );

        public function strip_php_tags($str)
        {
            return preg_replace('/&lt;\?php/i', '',
                preg_replace('/\?&gt;/', '', $str));
        }

        public function get_label()
        {
            $type_map = array(
                'is' => 'output is equal to',
                'contains' => 'output contains',
                'endswith' => 'output ends with',
                'startswith' => 'output starts with',
                'status' => 'return status is equal to',
            );
            if($params = $this->get_params()) {
                if(array_key_exists('value', $params)) {
                    return sprintf('PHP code %s \'%s\'', $type_map[$params['comparison_type']], $params['value']);
                }
            }
            return parent::get_label();
        }

        public function run($context)
        {
            $this->set_context($context);
            $params = $this->get_params();
            $script = $params['script'];
            list($cmd_out_arr, $cmd_status) = do_eval_php($script); 
            $cmd_out = implode("\n", $cmd_out_arr);
            $this->log('info', "got output: ".$cmd_out);
            $this->log('info', "cmd exit status: ".$cmd_status);

            switch($params['comparison_type']) {
                    case "is":
                        $result = $cmd_out == $params['value'];
                        break;
                    case "contains":
                        $result = strpos($cmd_out, $params['value']) !== FALSE;
                        break;
                    case "startswith":
                        $result = preg_match('/^'.$params['value'].'/i', $cmd_out);
                        break;
                    case "endswith":
                        $result = preg_match('/'.$params['value'].'$/i', $cmd_out);
                        break;
                    case "status":
                        $result = $cmd_status == $params['value'];
                        break;
                    default:
                        $result = FALSE;
            }
            $this->set_result((bool) $result);
        }
    }
